.. -*- mode: rst -*-

.. _api:

=================
API Documentation
=================

.. autosummary::
   :toctree: generated

   nibabel

.. the rest of the modules are relative to the top-level
.. currentmodule:: nibabel

File Formats
============

.. autosummary::
   :toctree: generated

   analyze
   spm2analyze
   spm99analyze
   gifti
   minc
   nicom
   nifti1
   parrec
   trackvis


Image Utilities
===============

.. autosummary::
   :toctree: generated

   eulerangles
   funcs
   imageclasses
   imageglobals
   loadsave
   orientations
   quaternions
   spatialimages
   volumeutils


Miscellaneous Helpers
=====================

.. autosummary::
   :toctree: generated

   arrayproxy
   batteryrunners
   fileholders
   filename_parser
   onetime
   tmpdirs
